Where encoded and unencoded versions of a string existed, removing
[privoxy.git] / project.h
index 8ad474e..c2896a4 100644 (file)
--- a/project.h
+++ b/project.h
@@ -1,6 +1,6 @@
 #ifndef PROJECT_H_INCLUDED
 #define PROJECT_H_INCLUDED
-#define PROJECT_H_VERSION "$Id: project.h,v 1.41 2001/10/28 19:12:06 jongfoster Exp $"
+#define PROJECT_H_VERSION "$Id: project.h,v 1.45 2002/01/09 14:33:27 oes Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/project.h,v $
  *
  * Revisions   :
  *    $Log: project.h,v $
+ *    Revision 1.45  2002/01/09 14:33:27  oes
+ *    Added HOSTENT_BUFFER_SIZE
+ *
+ *    Revision 1.44  2001/12/30 14:07:32  steudten
+ *    - Add signal handling (unix)
+ *    - Add SIGHUP handler (unix)
+ *    - Add creation of pidfile (unix)
+ *    - Add action 'top' in rc file (RH)
+ *    - Add entry 'SIGNALS' to manpage
+ *    - Add exit message to logfile (unix)
+ *
+ *    Revision 1.43  2001/11/22 21:57:51  jongfoster
+ *    Making action_spec->flags into an unsigned long rather than just an
+ *    unsigned int.
+ *    Adding ACTION_NO_COOKIE_KEEP
+ *
+ *    Revision 1.42  2001/11/05 21:42:41  steudten
+ *    Include DBG() macro.
+ *
  *    Revision 1.41  2001/10/28 19:12:06  jongfoster
  *    Adding ijb_toupper()
  *
@@ -407,6 +426,16 @@ typedef int jb_err;
  */
 #define BUFFER_SIZE 5000
 
+/*
+ * Buffer size for capturing struct hostent data in the
+ * gethostby(name|addr)_r library calls. Since we don't
+ * loop over gethostbyname_r, the buffer must be sufficient
+ * to accomodate multiple IN A RRs, as used in DNS round robin
+ * load balancing. W3C's wwwlib uses 1K, so that should be
+ * good enough for us, too.
+ */
+#define HOSTENT_BUFFER_SIZE 1024
+
 /*
  * So you can say "while (FOREVER) { ...do something... }"
  */
@@ -416,6 +445,10 @@ typedef int jb_err;
 #define HADDR_DEFAULT   "127.0.0.1"
 #define HADDR_PORT      8000
 
+/*
+ * pid file name
+ */
+#define PID_FILE_NAME   "junkbuster.pid"
 
 /* Forward defs for various structures */
 
@@ -470,6 +503,10 @@ struct http_request
 
    char *host_ip_addr_str; /* String with dotted decimal representation
                             * of host's IP. NULL before connect_to() */
+
+   char  *dbuffer;     /* Buffer with '\0'-delimited domain name.           */
+   char **dvec;        /* List of pointers to the strings in dbuffer.       */
+   int    dcount;      /* How many parts to this domain? (length of dvec)   */
 };
 
 /* Response generated by CGI, blocker, or error handler */
@@ -491,13 +528,11 @@ struct url_spec
    char  *spec;        /* The string which was parsed to produce this       */
                        /* url_spec.  Used for debugging or display only.    */
 
-   /* Hostname matching: */
-   char  *domain;      /* Fully qalified domain name (FQDN) pattern.        */
-                       /* May contain "*".                                  */
-   char  *dbuf;        /* Buffer with '\0'-delimited fqdn                   */
-   char **dvec;        /* Domain ptr vector into dbuf                       */
-   int    dcnt;        /* How many domains in fqdn?                         */
-   int    unanchored;  /* Bitmap - flags are ANCHOR_LEFT and ANCHOR_RIGHT   */
+   /* Hostname matching, or dbuffer == NULL to match all hosts */
+   char  *dbuffer;     /* Buffer with '\0'-delimited domain name.           */
+   char **dvec;        /* List of pointers to the strings in dbuffer.       */
+   int    dcount;      /* How many parts to this domain? (length of dvec)   */
+   int    unanchored;  /* Bitmap - flags are ANCHOR_LEFT and ANCHOR_RIGHT.  */
 
    /* Port matching: */
    int   port;         /* The port number, or 0 to match all ports.         */
@@ -511,9 +546,9 @@ struct url_spec
 #endif
 };
 #ifdef REGEX
-#define URL_SPEC_INITIALIZER { NULL, NULL, NULL, NULL, 0, 0, 0, NULL, 0, NULL }
+#define URL_SPEC_INITIALIZER { NULL, NULL, NULL, 0, 0, 0, NULL, 0, NULL }
 #else /* ifndef REGEX */
-#define URL_SPEC_INITIALIZER { NULL, NULL, NULL, NULL, 0, 0, 0, NULL, 0 }
+#define URL_SPEC_INITIALIZER { NULL, NULL, NULL, 0, 0, 0, NULL, 0 }
 #endif /* ndef REGEX */
 
 /* Constants for host part matching in URLs */
@@ -540,25 +575,26 @@ struct iob
 
 #define ACTION_MASK_ALL        (~0U)
 
-#define ACTION_MOST_COMPATIBLE 0x0000U
-
-#define ACTION_BLOCK           0x0001U
-#define ACTION_DEANIMATE       0x0002U
-#define ACTION_DOWNGRADE       0x0004U
-#define ACTION_FAST_REDIRECTS  0x0008U
-#define ACTION_FILTER          0x0010U
-#define ACTION_HIDE_FORWARDED  0x0020U
-#define ACTION_HIDE_FROM       0x0040U
-#define ACTION_HIDE_REFERER    0x0080U /* sic - follow HTTP, not English */
-#define ACTION_HIDE_USER_AGENT 0x0100U
-#define ACTION_IMAGE           0x0200U
-#define ACTION_IMAGE_BLOCKER   0x0400U
-#define ACTION_NO_COMPRESSION  0x0800U
-#define ACTION_NO_COOKIE_READ  0x1000U
-#define ACTION_NO_COOKIE_SET   0x2000U
-#define ACTION_NO_POPUPS       0x4000U
-#define ACTION_VANILLA_WAFER   0x8000U
-#define ACTION_LIMIT_CONNECT   0x010000U
+#define ACTION_MOST_COMPATIBLE 0x00000000UL
+
+#define ACTION_BLOCK           0x00000001UL
+#define ACTION_DEANIMATE       0x00000002UL
+#define ACTION_DOWNGRADE       0x00000004UL
+#define ACTION_FAST_REDIRECTS  0x00000008UL
+#define ACTION_FILTER          0x00000010UL
+#define ACTION_HIDE_FORWARDED  0x00000020UL
+#define ACTION_HIDE_FROM       0x00000040UL
+#define ACTION_HIDE_REFERER    0x00000080UL /* sic - follow HTTP, not English */
+#define ACTION_HIDE_USER_AGENT 0x00000100UL
+#define ACTION_IMAGE           0x00000200UL
+#define ACTION_IMAGE_BLOCKER   0x00000400UL
+#define ACTION_NO_COMPRESSION  0x00000800UL
+#define ACTION_NO_COOKIE_KEEP  0x00001000UL
+#define ACTION_NO_COOKIE_READ  0x00002000UL
+#define ACTION_NO_COOKIE_SET   0x00004000UL
+#define ACTION_NO_POPUPS       0x00008000UL
+#define ACTION_VANILLA_WAFER   0x00010000UL
+#define ACTION_LIMIT_CONNECT   0x00020000UL
 
 #define ACTION_STRING_DEANIMATE     0
 #define ACTION_STRING_FROM          1
@@ -580,7 +616,7 @@ struct iob
  */
 struct current_action_spec
 {
-   unsigned flags;    /* a bit set to "1" = add action    */
+   unsigned long flags;    /* a bit set to "1" = add action    */
 
    /* For those actions that require parameters: */
 
@@ -599,8 +635,8 @@ struct current_action_spec
  */
 struct action_spec
 {
-   unsigned mask;   /* a bit set to "0" = remove action */
-   unsigned add;    /* a bit set to "1" = add action    */
+   unsigned long mask;   /* a bit set to "0" = remove action */
+   unsigned long add;    /* a bit set to "1" = add action    */
 
    /* For those actions that require parameters: */
 
@@ -923,9 +959,28 @@ struct configuration_spec
 #endif /* def FEATURE_FORCE_LOAD */
 
 /* Hardwired URLs */
-#define HOME_PAGE_URL  "http://ijbswa.sourceforge.net"
-#define REDIRECT_URL HOME_PAGE_URL "/redirect.php?v=" VERSION "&to="
-#define CGI_PREFIX_HOST "i.j.b"
+#define HOME_PAGE_URL       "http://ijbswa.sourceforge.net"
+#define REDIRECT_URL        HOME_PAGE_URL "/redirect.php?v=" VERSION "&to="
+
+/*
+ * The "hosts" to intercept and display CGI pages.
+ * First one is a hostname only, second one can specify host and path.
+ *
+ * Notes:
+ * 1) Do not specify the http: prefix
+ * 2) CGI_SITE_2_PATH must not end with /, one will be added automatically.
+ * 3) CGI_SITE_2_PATH must start with /, unless it is the empty string.
+ */
+#define CGI_SITE_1_HOST "i.j.b"
+#define CGI_SITE_2_HOST "ijbswa.sourceforge.net"
+#define CGI_SITE_2_PATH "/config"
+
+/*
+ * The prefix for CGI pages.  Written out in generated HTML.
+ * INCLUDES the trailing slash.
+ */
+#define CGI_PREFIX  "http://" CGI_SITE_2_HOST CGI_SITE_2_PATH "/"
+
 
 /* HTTP snipplets */
 static const char CSUCCEED[] =